Index: /main/waeup.kofa/branches/henrik-regista/layout/error-zope.html
===================================================================
--- /main/waeup.kofa/branches/henrik-regista/layout/error-zope.html	(revision 11949)
+++ /main/waeup.kofa/branches/henrik-regista/layout/error-zope.html	(revision 11950)
@@ -3,5 +3,5 @@
   <head>
     <meta charset="utf-8">
-    <title>waeup.kofa Portal - Error</title>
+    <title>waeup.ikoba Portal - Error</title>
     <meta name="viewport" content="width=device-width, initial-scale=1.0">
     <meta name="description" content="">
@@ -14,9 +14,9 @@
     <link href="static/css/base.css" rel="stylesheet">
   </head>
-  <body id="kofa-body" class="errorpage">
+  <body id="ikoba-body" class="errorpage">
     <div class="container">
       <div class="jumbotron">
-        <h1 id="kofa-error-heading">Error</h1>
-        <div id="kofa-error-message">Error Message</div>
+        <h1 id="ikoba-error-heading">Error</h1>
+        <div id="ikoba-error-message">Error Message</div>
         <div>We are terribly sorry.</div>
       </div>
Index: /main/waeup.kofa/branches/henrik-regista/layout/static/css/base.css
===================================================================
--- /main/waeup.kofa/branches/henrik-regista/layout/static/css/base.css	(revision 11949)
+++ /main/waeup.kofa/branches/henrik-regista/layout/static/css/base.css	(revision 11950)
@@ -27,5 +27,5 @@
 }
 
-.kofa-langselect img {
+.ikoba-langselect img {
     margin-top: -10px;
     margin-bottom: -10px;
@@ -64,10 +64,10 @@
 /* Kofa styles */
 
-.kofa-sidebar,
-.kofa-content-narrow,
-.kofa-content-wide,
-.kofa-breadcrumbs-box-short,
-.kofa-breadcrumbs-box-long,
-.kofa-student-status-box {
+.ikoba-sidebar,
+.ikoba-content-narrow,
+.ikoba-content-wide,
+.ikoba-breadcrumbs-box-short,
+.ikoba-breadcrumbs-box-long,
+.ikoba-student-status-box {
     padding: 0px 5px 0px 5px;
 }
@@ -83,15 +83,15 @@
 }
 
-.kofa-breadcrumbs-box-short .well,
-.kofa-breadcrumbs-box-long .well,
-.kofa-student-status-box .well {
+.ikoba-breadcrumbs-box-short .well,
+.ikoba-breadcrumbs-box-long .well,
+.ikoba-student-status-box .well {
     padding: 5px 5px 5px 5px;
 }
 
-.kofa-content-wide .well, .kofa-content-narrow .well {
+.ikoba-content-wide .well, .ikoba-content-narrow .well {
     padding: 10px 20px 10px 20px;
 }
 
-.kofa-content-desc {
+.ikoba-content-desc {
     color: #BFBFBF;
     font-size: 18px;
@@ -104,5 +104,5 @@
 }
 
-.kofa-student-status-box .well {
+.ikoba-student-status-box .well {
     background-color: #909090;
 }
@@ -117,5 +117,5 @@
 /* Sidebar */
 
-.kofa-sidebar-title {
+.ikoba-sidebar-title {
     text-transform: none;
     font-size: 14px;
@@ -324,13 +324,13 @@
 @media (max-width: 767px) {
 
-  .kofa-sidebar,
-  .kofa-content-narrow ,
-  .kofa-breadcrumbs-box-short,
-  .kofa-breadcrumbs-box-long,
-  .kofa-student-status-box {
+  .ikoba-sidebar,
+  .ikoba-content-narrow ,
+  .ikoba-breadcrumbs-box-short,
+  .ikoba-breadcrumbs-box-long,
+  .ikoba-student-status-box {
       padding: 0px 0px 0px 0px;
   }
 
-  .kofa-content-wide {
+  .ikoba-content-wide {
       padding: 0px 0px 0px 0px;
   }
Index: /main/waeup.kofa/branches/henrik-regista/layout/theme.html
===================================================================
--- /main/waeup.kofa/branches/henrik-regista/layout/theme.html	(revision 11949)
+++ /main/waeup.kofa/branches/henrik-regista/layout/theme.html	(revision 11950)
@@ -27,5 +27,5 @@
     <![endif]-->
 
-    <script src="static/js/kofa-functions.js"></script>
+    <script src="static/js/ikoba-functions.js"></script>
 
     <!-- icons -->
@@ -35,19 +35,19 @@
   </head>
 
-  <body id="kofa-body">
+  <body id="ikoba-body">
 
     <div class="navbar navbar-inverse navbar-fixed-top" role="navigation">
       <div class="navbar-header">
         <button type="button" class="navbar-toggle" data-toggle="collapse"
-                  data-target="#kofa-primary-nav">
+                  data-target="#ikoba-primary-nav">
           <span class="icon-bar"></span>
           <span class="icon-bar"></span>
           <span class="icon-bar"></span>
         </button>
-        <a class="navbar-brand active kofa-brand-link" href="/">WAeUP.Kofa</a>
+        <a class="navbar-brand active ikoba-brand-link" href="/">WAeUP.Ikoba</a>
       </div>
       <div class="navbar-collapse collapse"
-           id="kofa-primary-nav">
-        <ul class="nav navbar-nav kofa-navbar-left">
+           id="ikoba-primary-nav">
+        <ul class="nav navbar-nav ikoba-navbar-left">
           <li class="active"><a href="#">Academics</a></li>
           <li><a href="#about">Applicants</a></li>
@@ -67,16 +67,16 @@
         </ul>
 
-        <ul class="nav navbar-nav navbar-right kofa-navbar-right">
-          <li class="dropdown kofa-langselect">
+        <ul class="nav navbar-nav navbar-right ikoba-navbar-right">
+          <li class="dropdown ikoba-langselect">
             <a href="#" class="dropdown-toggle"
                data-toggle="dropdown">
                <img src="static/img/earth.png" />
             <ul class="dropdown-menu">
-              <li class="kofa-language"><a href="#">English</a></li>
-              <li class="kofa-language"><a href="#">Français</a></li>
-              <li class="kofa-language"><a href="#">Deutsch</a></li>
-              <li class="kofa-language"><a href="#">Hausa</a></li>
-              <li class="kofa-language"><a href="#">Yoruba</a></li>
-              <li class="kofa-language"><a href="#">Igbo</a></li>
+              <li class="ikoba-language"><a href="#">English</a></li>
+              <li class="ikoba-language"><a href="#">Français</a></li>
+              <li class="ikoba-language"><a href="#">Deutsch</a></li>
+              <li class="ikoba-language"><a href="#">Hausa</a></li>
+              <li class="ikoba-language"><a href="#">Yoruba</a></li>
+              <li class="ikoba-language"><a href="#">Igbo</a></li>
             </ul>
           </li>
@@ -90,7 +90,7 @@
 
       <div class="row">
-        <div class="col-md-12 container kofa-breadcrumbs-box-long">
+        <div class="col-md-12 container ikoba-breadcrumbs-box-long">
           <div class="well">
-            <ol class="breadcrumb kofa-breadcrumbs">
+            <ol class="breadcrumb ikoba-breadcrumbs">
               <li>
                 <a href="#">
@@ -113,13 +113,13 @@
                 </a>
               </li>
-            </ol><!-- /kofa-breadcrumbs -->
+            </ol><!-- /ikoba-breadcrumbs -->
           </div> <!-- /well -->
-        </div> <!-- /kofa-breadcrumbs-box-short -->
+        </div> <!-- /ikoba-breadcrumbs-box-short -->
       </div>
 
       <div class="row">
-        <div class="col-md-8 container kofa-breadcrumbs-box-short">
+        <div class="col-md-8 container ikoba-breadcrumbs-box-short">
           <div class="well">
-            <ol class="breadcrumb kofa-breadcrumbs">
+            <ol class="breadcrumb ikoba-breadcrumbs">
               <li>
                 <a href="#">
@@ -142,9 +142,9 @@
                 </a>
               </li>
-            </ol><!-- /kofa-breadcrumbs -->
+            </ol><!-- /ikoba-breadcrumbs -->
           </div> <!-- /well -->
-        </div> <!-- /kofa-breadcrumbs-box-short -->
-
-        <div class="col-md-4 container kofa-student-status-box">
+        </div> <!-- /ikoba-breadcrumbs-box-short -->
+
+        <div class="col-md-4 container ikoba-student-status-box">
           <div class="well">
             <div class="wfstatus">
@@ -152,13 +152,13 @@
             </div> <!-- /wfstatus -->
           </div> <!-- /well -->
-        </div> <!-- /kofa-student-status-box -->
+        </div> <!-- /ikoba-student-status-box -->
 
       </div> <!-- /row -->
 
       <div class="row">
-        <div class="col-md-2 kofa-sidebar">
+        <div class="col-md-2 ikoba-sidebar">
           <div class="sidebar-nav well">
             <div>
-              <div class="kofa-sidebar-title">Student Name</div>
+              <div class="ikoba-sidebar-title">Student Name</div>
               <ul class="nav">
                 <li><a href="#">Base Data</a></li>
@@ -172,5 +172,5 @@
             </div>
             <div>
-              <div class="kofa-sidebar-title">Manager Name</div>
+              <div class="ikoba-sidebar-title">Manager Name</div>
               <ul class="nav">
                 <li><a href="#">Portal Configuration</a></li>
@@ -184,9 +184,9 @@
             </div>
           </div> <!-- /well -->
-        </div> <!-- /kofa-sidebar -->
-
-        <div class="col-md-10 content kofa-content-narrow">
+        </div> <!-- /ikoba-sidebar -->
+
+        <div class="col-md-10 content ikoba-content-narrow">
           <div class="well">
-            <div class="kofa-content">
+            <div class="ikoba-content">
               <div class="actionbar">
                 <a class="btn btn-default" href="">
@@ -210,8 +210,8 @@
                   You have successfully ...
               </div>
-              <h1>WAeUP.Kofa Theme</h1>
-
-              <p class="kofa-content-desc">
-                A sample Diazo theme for WAeUP.Kofa
+              <h1>WAeUP.Ikoba Theme</h1>
+
+              <p class="ikoba-content-desc">
+                A sample Diazo theme for WAeUP.Ikoba
                 <br />
                 Fusce dapibus, tellus ac cursus commodo.
@@ -309,12 +309,12 @@
 
               </div><!-- /tab-content -->
-            </div> <!-- /kofa-content -->
+            </div> <!-- /ikoba-content -->
           </div> <!-- /well -->
-        </div> <!-- /kofa-content-narrow -->
+        </div> <!-- /ikoba-content-narrow -->
       </div> <!-- /row -->
 
       <div class="row">
-        <div class="col-md-12 content kofa-content-wide">
-          <div class="well kofa-content">
+        <div class="col-md-12 content ikoba-content-wide">
+          <div class="well ikoba-content">
             <div class="actionbar">
               <a class="btn btn-default" href="">
@@ -501,5 +501,5 @@
                 <tr>
                   <td class="fieldname">
-                      A select field in Kofa pagetemplates:
+                      A select field in Ikoba pagetemplates:
                   </td>
                   <td>
@@ -517,10 +517,10 @@
               </tbody>
             </table>
-          </div> <!-- /well kofa-content-->
-        </div> <!-- /kofa-content-wide -->
+          </div> <!-- /well ikoba-content-->
+        </div> <!-- /ikoba-content-wide -->
       </div> <!-- /row -->
       <div id="bottom" class="footer">
         <p class="credit muted text-right">
-          Kofa - Student Management System<br />
+          Ikoba - Applocation & Registration System<br />
           Copyright &copy; WAeUP Group
           <script type="text/javascript">
@@ -533,22 +533,22 @@
     <script src="https://code.jquery.com/jquery-1.9.1.min.js"></script>
     <script src="static/bootstrap/js/bootstrap.min.js"></script>
-    <script src="static/js/kofa-scroll.js"></script>
-    <script src="static/js/kofa-activate-tab.js"></script>
-    <script src="static/js/kofa-scrollto.js"></script>
+    <script src="static/js/ikoba-scroll.js"></script>
+    <script src="static/js/ikoba-activate-tab.js"></script>
+    <script src="static/js/ikoba-scrollto.js"></script>
     <script src="static/js/file-upload.js"></script>
-    <script class="kofa-script-tooltip"
-        src="static/js/kofa-tooltip.js">
+    <script class="ikoba-script-tooltip"
+        src="static/js/ikoba-tooltip.js">
     </script>
-    <script class="kofa-script-datatable"
+    <script class="ikoba-script-datatable"
         src="static/js/jquery.dataTables.min.js">
     </script>
-    <script class="kofa-script-datatable"
-        src="static/js/kofa-datatables.js">
+    <script class="ikoba-script-datatable"
+        src="static/js/ikoba-datatables.js">
     </script>
     <script class="jquery-ui"
         src="static/js/jquery-ui.min.js">
     </script>
-    <script class="kofa-script-datepicker"
-        src="static/js/kofa-datepicker.js">
+    <script class="ikoba-script-datepicker"
+        src="static/js/ikoba-datepicker.js">
     </script>
   </body>
Index: /main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/frontpage.html
===================================================================
--- /main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/frontpage.html	(revision 11949)
+++ /main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/frontpage.html	(revision 11950)
@@ -1,5 +1,5 @@
-<h1>Welcome to WAeUP.Kofa
+<h1>Welcome to WAeUP.Ikoba
 <br>
-<p class="kofa-content-desc">
+<p class="ikoba-content-desc">
 the Information and Registration Portal
 for Schools, Colleges and Universities
@@ -9,5 +9,5 @@
 <p>
 This is the default frontpage written in HTML.
-Kofa's CSS design is based on Twitter's Bootstrap. Visit the
+Ikoba's CSS design is based on Twitter's Bootstrap. Visit the
 <a href="http://getbootstrap.com/">Bootstrap documentation</a>
 for further information.
@@ -15,5 +15,5 @@
 
 <p>
-Kofa is part of the
+Ikoba is part of the
 <a href="https://waeup.org/">West African eUniversity Project (WAeUP)</a>.
 It is a powerful and comprehensive Student Management System.
@@ -52,5 +52,5 @@
 
 >>de<<
-<h1>Willkommen auf WAeUP.Kofa,
+<h1>Willkommen auf WAeUP.Ikoba,
 <br>
 <small>
@@ -61,5 +61,5 @@
 <p>
 Dies ist die Standard-Startseite des Portals, die in HTML geschrieben wurde.
-Kofas css-Design basiert auf Twitters Bootstrap. Besuchen Sie die
+Ikobas css-Design basiert auf Twitters Bootstrap. Besuchen Sie die
 <a href="http://twitter.github.com/bootstrap/">Bootstrap-Dokumentation</a>
 auf GitHub, um weitere Informationen zu erhalten.
@@ -67,5 +67,5 @@
 
 <p>
-Kofa ist Teil des
+Ikoba ist Teil des
 <a href="https://waeup.org/">West African eUniversity Project (WAeUP)</a>.
 Es ist ein leistungsstarkes and umfassendes Student Management System, welches
Index: /main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/mail.zcml
===================================================================
--- /main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/mail.zcml	(revision 11949)
+++ /main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/mail.zcml	(revision 11950)
@@ -29,5 +29,5 @@
    background thread and sends mail independently from requests.
 
-   By default in KOFA we have a fake mailer activated, that does not
+   By default in Ikoba we have a fake mailer activated, that does not
    send real mail to the outside world.
   -->

Index: /main/waeup.kofa/branches/henrik-regista/layout/static/js/kofa-scrollto.js
===================================================================
--- /main/waeup.kofa/branches/henrik-regista/layout/static/js/kofa-scrollto.js	(revision 11949)
+++ /main/waeup.kofa/branches/henrik-regista/layout/static/js/kofa-scrollto.js	(revision 11950)
@@ -1,6 +1,6 @@
 /* After loading the page, softly scroll to the #kofa-scroll-target tag,
    if it exists */
 $(document).ready(function (){
-    var scroll_target = $('#kofa-scroll-target');
+    var scroll_target = $('#ikoba-scroll-target');
     if (scroll_target.length) {
 	$('html,body').animate(
@@ -1,6 +1,6 @@
-/* After loading the page, softly scroll to the #kofa-scroll-target tag,
+/* After loading the page, softly scroll to the #ikoba-scroll-target tag,
    if it exists */
 $(document).ready(function (){